.. result

Welcome to result's documentation!
==================================

A fully type-annotated Rust-like Result type for Python.

.. toctree::
   :maxdepth: -1
   :caption: Table of Contents

    API Reference <modules>
    CHANGELOG <changelog>
    CONTRIBUTING <contributing>
    README <readme>


Indices and Tables
==================

* :ref:`genindex`
* :ref:`modindex`
